﻿CREATE TABLE dbo.Memo
(
    ID            INT           IDENTITY(1, 1) PRIMARY KEY, -- ID
    Title         NVARCHAR(100) NOT NULL,                   -- 제목
    MailAddress   NVARCHAR(100) NULL,                       -- 메일 주소
    [Description] NVARCHAR(500) NOT NULL,                   -- 설명
    WriteDate     DATETIME      DEFAULT(GETDATE()),         -- 작성일
    WriteIP       NVARCHAR(15)  NULL                        -- 작성 IP 주소
)
GO

INSERT INTO dbo.Memo
VALUES
(
    N'메모1',
    N'test@daum.com',
    N'테스트 문자열',
    GetDate(),
    '127.0.0.1'
)
Go

SELECT
    ID
   ,Title
   ,MailAddress
   ,[Description]
   ,WriteDate
   ,WriteIP
FROM dbo.Memo
ORDER BY ID DESC
GO

SELECT
    ID
   ,Title
   ,MailAddress
   ,[Description]
   ,WriteDate
   ,WriteIP
FROM  dbo.Memo
WHERE ID = 1
GO

BEGIN TRANSACTION
    UPDATE dbo.Memo
    SET
        Title         = N'메모1 (수정)',
        MailAddress   = N'test@daum.com',
        [Description] = N'테스트 문자열 (수정)',
        WriteIP       = N'127.0.0.1'
    Where ID = 1
COMMIT TRANSACTION
GO

BEGIN TRANSACTION
    DELETE FROM dbo.Memo
    Where  ID = 10
COMMIT TRAN
GO

SELECT
    ID
   ,Title
   ,MailAddress
   ,[Description]
   ,WriteDate
   ,WriteIP
From  dbo.Memo
Where Title       = '메모1'
Or    MailAddress Like '%test%'
ORDER BY ID DESC
GO

CREATE PROCEDURE dbo.WriteMemo(@Title NVARCHAR(100), @MailAddress NVARCHAR(100), @Description NVARCHAR(500), @WriteIP NVARCHAR(15))
AS
    INSERT INTO dbo.Memo
    (
        Title
       ,MailAddress
       ,[Description]
       ,WriteIP
    )
    Values
    (
        @Title
       ,@MailAddress
       ,@Description
       ,@WriteIP
    )
GO

CREATE PROCEDURE dbo.ListMemo
AS
    SELECT
        ID
       ,Title
       ,MailAddress
       ,[Description]
       ,WriteDate
       ,WriteIP
    FROM dbo.Memo
    ORDER BY ID DESC
GO

CREATE PROCEDURE dbo.ViewMemo(@ID INT)
AS
    SELECT
        ID
       ,Title
       ,MailAddress
       ,[Description]
       ,WriteDate
       ,WriteIP
    FROM  dbo.Memo
    WHERE ID = @ID
GO

CREATE PROCEDURE dbo.UpdateMemo(@Title NVARCHAR(100), @MailAddress NVARCHAR(100), @Description NVARCHAR(150), @ID INT)
AS
BEGIN TRANSACTION
    UPDATE dbo.Memo
    SET
        Title         = @Title
       ,MailAddress   = @MailAddress
       ,[Description] = @Description
    Where ID = @ID
COMMIT TRANSACTION
GO

CREATE PROCEDURE dbo.DeleteMemo(@ID INT)
AS
    DELETE FROM dbo.Memo
    Where  ID = @ID
GO

CREATE PROCEDURE dbo.SearchMemo(@SearchField NVARCHAR(100), @SearchQuery NVARCHAR(100))
AS
    DECLARE @SQL NVARCHAR(1000)

    SET @SQL = '
SELECT
    ID
   ,Title
   ,MailAddress
   ,[Description]
   ,WriteDate
   ,WriteIP
FROM dbo.Memo
WHERE ' + @SearchField + ' LIKE N''%' + @SearchQuery + '%''
ORDER BY ID DESC
'

    EXECUTE SP_EXECUTESQL @SQL
GO