﻿using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;

using TestProject.Models;

namespace TestProject
{
    /// <summary>
    /// 수정 페이지
    /// </summary>
    public partial class UpdatePage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 페이지 로드시 처리하기 - Page_Load(sender, e)

        /// <summary>
        /// 페이지 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if(string.IsNullOrEmpty(Request["ID"]))
            {
                Response.Write("잘못된 요청입니다.");

                Response.End();
            }
            else
            {
                if(!Page.IsPostBack)
                {
                    DisplayData();
                }
            }
        }

        #endregion
        #region 수정 버튼 클릭시 처리하기 - updateButton_Click(sender, e)

        /// <summary>
        /// 수정 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void updateButton_Click(object sender, EventArgs e)
        {
            MemoModel memo = new MemoModel();

            memo.ID          = Convert.ToInt32(Request["ID"]);
            memo.Title       = this.titleTextBox.Text;
            memo.MailAddress = this.mailAddressTextBox.Text;
            memo.Description = this.descriptionTextBox.Text;

            string connectionString = ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString;

            SqlConnection connection = new SqlConnection(connectionString);

            connection.Open();

            SqlCommand command = new SqlCommand("UpdateMemo", connection);

            command.CommandType = CommandType.StoredProcedure;

            command.Parameters.AddWithValue("@Title"      , memo.Title      );
            command.Parameters.AddWithValue("@MailAddress", memo.MailAddress);
            command.Parameters.AddWithValue("@Description", memo.Description);
            command.Parameters.AddWithValue("@ID"         , memo.ID         );

            command.ExecuteNonQuery();

            connection.Close();

            Response.Redirect("ViewPage.aspx?ID=" + Request["ID"]); 
        }

        #endregion
        #region 목록 버튼 클릭시 처리하기 - listButton_Click(sender, e)

        /// <summary>
        /// 목록 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void listButton_Click(object sender, EventArgs e)
        {
            Response.RedirectPermanent("ListPage.aspx");
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 데이터 표시하기 - DisplayData()

        /// <summary>
        /// 데이터 표시하기
        /// </summary>
        private void DisplayData()
        {
            string id = Request["ID"];

            string connectionString = ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString;

            SqlConnection conection = new SqlConnection(connectionString);

            conection.Open();

            SqlCommand command = new SqlCommand("ViewMemo", conection);

            command.CommandType = CommandType.StoredProcedure;

            command.Parameters.Add("ID", SqlDbType.Int);

            command.Parameters["ID"].Value = Convert.ToInt32(id);

            SqlDataReader reader = command.ExecuteReader();

            if(reader.Read())
            {
                this.idLabel.Text            = Request["ID"];
                this.titleTextBox.Text       = reader["Title"      ].ToString();
                this.mailAddressTextBox.Text = reader["MailAddress"].ToString();
                this.descriptionTextBox.Text = reader["Description"].ToString();
            }
            else
            {
                Response.Write("존재하지 않는 데이터 입니다.");

                Response.End();
            }

            reader.Close();

            conection.Close();
        }

        #endregion
    }
}